<?php
App::uses('AppModel', 'Model');

class LateBookingPackage extends BuzzLateBookingsAppModel {

	/**
	 * Behaviors
	 *
	 * @var array
	 */
	public $actsAs = array(
		'BuzzTranslate.Translatable'
	);

	/**
	 * Validation rules
	 *
	 * @var array
	 */
	public $validate = array(
		'activity_api_reference' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'Required'
			),
			'max' => array(
				'rule' => array('maxLength', 80),
				'message' => 'No more than 80 characters long',
			)
		),
		'package_api_reference' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'Required'
			),
			'max' => array(
				'rule' => array('maxLength', 80),
				'message' => 'No more than 80 characters long',
			)
		),
		'api_additional_notes' => array(
			'max' => array(
				'rule' => array('maxLength', 250),
				'message' => 'No more than 250 characters long',
				'allowEmpty' => true
			)
		),
		'api_discount_code' => array(
			'max' => array(
				'rule' => array('maxLength', 45),
				'message' => 'No more than 45 characters long',
				'allowEmpty' => true
			)
		),
		'participants' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'Required'
			),
		),
		'name' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'Required'
			),
			'max' => array(
				'rule' => array('maxLength', 150),
				'message' => 'No more than 150 characters long'
			)
		),
		'activity_id' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'Required'
			),
			'upsells' => array(
				'rule' => 'validateActivityForUpsells',
				'message' => 'Multi-experience packages cannot have upsells'
			)
		),
		'peak_price' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'Required'
			),
			'decimal' => array(
				'rule' => '|^\d+(\.\d{2})?$|',
				'message' => 'Decimal numbers only'
			)
		),
		'off_peak_price' => array(
			'decimal' => array(
				'rule' => '|^\d+(\.\d{2})?$|',
				'message' => 'Decimal numbers only',
				'allowEmpty' => true
			)
		),
		'upsell_price' => array(
			'require' => array(
				'rule' => 'validateRequireForUpsells',
				'message' => 'Required'
			),
			'decimal' => array(
				'rule' => '|^\d+(\.\d{2})?$|',
				'message' => 'Decimal numbers only',
				'allowEmpty' => true
			)
		),
		'sequence' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'Required'
			),
			'max' => array(
				'rule' => array('naturalNumber', true)
			)
		)
	);

	/**
	 * Image slots
	 *
	 * @var array
	 */
	public $imageSlots = [
		'main' => [
			'slots' => 1,
			'fields' => []
		]
	];

}
